@@ -8,7 +8,8 @@ from orm_collector.models import (Station,
                                   DBData,
                                   DBType,
                                   DataDestiny,
-                                  ServerInstance)
+                                  ServerInstance,
+                                  NetworkGroup)
 
 from orm_collector.db_session import CollectorSession, data
 
@@ -27,7 +28,7 @@ def object_as_dict(obj):
             for c in inspect(obj).mapper.column_attrs}
 
 
-class SessionHandle:
+class SessionHandle(CollectorSession):
     """
     A session middleware class to manage the basic elements in the database,
     has generic methods to verify the elements existence, update_ and obtain
@@ -35,10 +36,8 @@ class SessionHandle:
     """
 
     def __init__(self, *args, **kwargs):
-        session = CollectorSession(**kwargs.get("dbdata"))
-        self.engine = session.engine
-        self.session = session
-        self.conn = session.connection
+        super().__init__(*args, **kwargs)
+        self.conn = self.connection
         self.metadata = MetaData()
         code = kwargs.get('code', 'ORM')
         log_path = kwargs.get('log_path', './')
@@ -217,9 +216,9 @@ class SessionCollector(SH):
         interface_port = int(kwargs.get('interface_port'))
         db = kwargs.get('db')
         protocol = kwargs.get('protocol')
-        server_id = kwargs.get('server_id', 0)
+        server = kwargs.get('server_id', "atlas")
         active = kwargs.get('active', False)
-
+        network = kwargs.get("network_id","3g")
         instance = self.session.query(Station).filter_by(code=code).first()
         if instance:
             self.logger.info("Estación %s ya existe" % instance)
@@ -230,6 +229,7 @@ class SessionCollector(SH):
                 # check if db and protocol exists
                 db_e = object
                 prot_e = object
+                network_id = object
                 if isinstance(db, int):
                     db_e = self.get_dbdata_by_id(db)
                     db_id = db_e.id
@@ -243,7 +243,18 @@ class SessionCollector(SH):
 
                     prot_e = self.get_protocol_id(protocol)
                     prot_id = prot_e.id
-
+                if isinstance(server, str) and not server.isdigit():
+                    server_e = self.get_server_id(server.upper())
+                    server_id = server_e.id
+                elif server.isdigit():
+                    server_e = self.get_server_by_id(server)
+                    server_id = server_e.id
+                if isinstance(network, int):
+                    network_e = self.get_network_by_id(network.upper())
+                    network_id = network_e.id
+                else:
+                    network_e = self.get_network_id(network)
+                    network_id = network_e.id
                 if db_e and prot_e:
                     station = Station(code=code,
                                       name=name,
@@ -257,7 +268,8 @@ class SessionCollector(SH):
                                       db_id=db_id,
                                       protocol_id=prot_id,
                                       active=active,
-                                      server_id=server_id)
+                                      server_id=server_id,
+                                      network_id=network_id)
                     self.create_station(station)
                     self.logger.info("Creada nueva estación %s" % instance)
                     return station
@@ -358,10 +370,66 @@ class SessionCollector(SH):
         sql_query = sql_query_tpl.replace("[SERVER_ID]",
                                           str(server.id)).replace("[ACTIVE]", active)
         file_q.close()
+        print("Consulta--->", sql_query)
         stmt = text(sql_query)
         result = self.session.execute(stmt)
         return result
 
+    # Network Group
+
+    def network(self, **kwargs):
+        if kwargs:
+            name = kwargs.get('name', "3g").upper()
+            description = kwargs.get("description", "Red de celular")
+        network = self.session.query(
+            NetworkGroup).filter_by(name=name).first()
+        if network:
+            self.logger.info("network ya exitse, %s" % network)
+            return network
+        else:
+            network = NetworkGroup(
+                name=name,
+                description=description)
+            self.create_network(network)
+            self.logger.info("Nuevo network creado, %s" % network)
+            return network
+
+    def create_network(self, network):
+        self.session.add(network)
+        self.session.commit()
+
+    def update_network(self, instance, fields, values):
+        t_name = 'network_instance'
+        assert len(fields) == len(values)
+        for i, f in enumerate(fields):
+            v = values[i]
+            self.update_table(t_name, instance, f, v)
+
+    def delete_network(self, network):
+        self.session.delete(network)
+        self.session.flush()
+
+    def get_network(self):
+        return self.get_list(NetworkGroup)
+
+    def get_network_id(self, name):
+        # code is a unique value
+        u = self.session.query(NetworkGroup).filter_by(name=name.upper()).all()
+        if u:
+            return u[0]
+        else:
+            return None
+
+    def get_network_by_id(self, pk):
+        u = self.session.query(NetworkGroup).filter_by(id=pk).all()
+        if u:
+            return u[0]
+        else:
+            return None
+
+
+    
+
     # Server Instance
 
     def server(self, **kwargs):
@@ -410,7 +478,7 @@ class SessionCollector(SH):
 
     def get_server_id(self, name):
         # code is a unique value
-        u = self.session.query(ServerInstance).filter_by(host_name=name).all()
+        u = self.session.query(ServerInstance).filter_by(ServerInstance.host_name.ilike(name)).all()
         if u:
             return u[0]
         else:
